
# Swarms Cloud

[![Join our Discord](https://img.shields.io/badge/Discord-Join%20our%20server-5865F2?style=for-the-badge&logo=discord&logoColor=white)](https://discord.gg/agora-999382051935506503) [![Subscribe on YouTube](https://img.shields.io/badge/YouTube-Subscribe-red?style=for-the-badge&logo=youtube&logoColor=white)](https://www.youtube.com/@kyegomez3242) [![Connect on LinkedIn](https://img.shields.io/badge/LinkedIn-Connect-blue?style=for-the-badge&logo=linkedin&logoColor=white)](https://www.linkedin.com/in/kye-g-38759a207/) [![Follow on X.com](https://img.shields.io/badge/X.com-Follow-1DA1F2?style=for-the-badge&logo=x&logoColor=white)](https://x.com/kyegomezb)

Infrastructure for scalable, reliable, and economical Multi-Modal Model API serving and deployment. We're using terraform to orchestrate infrastructure, FastAPI to host the models. If you're into deploying models for millions of people, join our discord and help contribute.

# Install
```bash

$ pip3 install -U swarms-cloud

```

# Stack
- Backend: FastAPI
- Skypilot for container management
- Postresql for database
- Docker for cluster management
- Terraform

# APIS
- Agent API
- Swarms Memory API
- OES API
- Swarms Multi-Agent API  
  - Parallel API
  - Sequential API
  - Hiearchical API Etc
  

# License
MIT

## References
- [Noam tweet](https://x.com/NoamShazeer/status/1803790708358410380)
